==> haskell-tls-session-manager-0.0.0.1-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tls-session-manager
version: 0.0.0.1
id: tls-session-manager-0.0.0.1-59cryDsGkJ71LtGIGBQn4y
key: tls-session-manager-0.0.0.1-59cryDsGkJ71LtGIGBQn4y
license: BSD3
maintainer: kazu@iij.ad.jp
synopsis: In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance
category: Web
author: Kazu Yamamoto
exposed: True
indefinite: False
exposed-modules:
    Network.TLS.SessionManager
abi: dbe517efea617edec8cbd97fc62e0267
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/tls-session-manager-0.0.0.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/tls-session-manager-0.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/tls-session-manager-0.0.0.1
hs-libraries: HStls-session-manager-0.0.0.1-59cryDsGkJ71LtGIGBQn4y
depends:
    base-4.10.0.0 auto-update-0.1.4-GZpbAgyETDJHs1aXX3MWAW
    clock-0.7.2-9fV7rV7wNUo6v6mDurfiVg
    psqueues-0.2.3.0-CwAzjDDqYyqJcuhMywfrrv
    tls-1.4.0-59P2QRjXtqq6Og4afpGkIb
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             auto-update-0.1.4-GZpbAgyETDJHs1aXX3MWAW=05dc294e863651d9a465fdf5002212e6
             clock-0.7.2-9fV7rV7wNUo6v6mDurfiVg=1e1baf841d0fcad1b9eca88e567ce03e
             psqueues-0.2.3.0-CwAzjDDqYyqJcuhMywfrrv=c9472969e2d5d69948499c4e01f48a1d
             tls-1.4.0-59P2QRjXtqq6Og4afpGkIb=34e6115d3d7ce4ec13877f3be52d3890
haddock-interfaces: /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock
haddock-html: /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tls-session-manager-0.0.0.1-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tls-session-manager
version: 0.0.0.1
id: tls-session-manager-0.0.0.1-GmvWRMwKlgw3p3Ss5KCCbX
key: tls-session-manager-0.0.0.1-GmvWRMwKlgw3p3Ss5KCCbX
license: BSD3
maintainer: kazu@iij.ad.jp
synopsis: In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance
category: Web
author: Kazu Yamamoto
exposed: True
indefinite: False
exposed-modules:
    Network.TLS.SessionManager
abi: 1b0402e11e9f1d4dc30b4ad9fb2b3128
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/tls-session-manager-0.0.0.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/tls-session-manager-0.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/tls-session-manager-0.0.0.1
hs-libraries: HStls-session-manager-0.0.0.1-GmvWRMwKlgw3p3Ss5KCCbX
depends:
    base-4.10.0.0 auto-update-0.1.4-GZpbAgyETDJHs1aXX3MWAW
    clock-0.7.2-9fV7rV7wNUo6v6mDurfiVg
    psqueues-0.2.3.0-CwAzjDDqYyqJcuhMywfrrv
    tls-1.4.0-AIGDBTjdUtf9A67P6hVDPj
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             auto-update-0.1.4-GZpbAgyETDJHs1aXX3MWAW=05dc294e863651d9a465fdf5002212e6
             clock-0.7.2-9fV7rV7wNUo6v6mDurfiVg=1e1baf841d0fcad1b9eca88e567ce03e
             psqueues-0.2.3.0-CwAzjDDqYyqJcuhMywfrrv=c9472969e2d5d69948499c4e01f48a1d
             tls-1.4.0-AIGDBTjdUtf9A67P6hVDPj=b8268e85bfbdae5349c8ffbca2d8e1d6
haddock-interfaces: /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock
haddock-html: /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
